Replace config/project repos with config/untrusted projects

The config-repo / project-repo terminology is confusing and we've
generally been using trusted-project and untrusted-project instead.
The term "untrusted-project" is straightforward, but "trusted-project"
is a little misleading, since there are other characteristics which
define it (notably, that the configuration held in it is branchless).
A better term for that might be "config-project".

Since the main config now directly refers to projects rather than
repos, complete the transition by replacing all config-repo
occurances with config-project and likewise project-repo with
untrusted-project.

Change-Id: I2341aa94e3622e2647b0506b78bc84dbcdec1901
Story: 2000953
diff --git a/zuul/model.py b/zuul/model.py
index 7dfd10f..cc62dfb 100644
--- a/zuul/model.py
+++ b/zuul/model.py
@@ -2512,16 +2512,16 @@
         # The unparsed configuration from the main zuul config for
         # this tenant.
         self.unparsed_config = None
         # The list of repos from which we will read main
         # configuration.
-        self.config_repos = []
-        # The unparsed config from those repos.
-        self.config_repos_config = None
-        # The list of projects from which we will read in-repo
-        # configuration.
-        self.project_repos = []
-        # The unparsed config from those repos.
-        self.project_repos_config = None
+        self.config_projects = []
+        # The unparsed config from those projects.
+        self.config_projects_config = None
+        # The list of projects from which we will read untrusted
+        # in-repo configuration.
+        self.untrusted_projects = []
+        # The unparsed config from those projects.
+        self.untrusted_projects_config = None
         self.semaphore_handler = SemaphoreHandler()
 
         # A mapping of project names to projects.  project_name ->
@@ -2579,20 +2579,20 @@
                                     "with a hostname" % (name,))
         if project is None:
             return (None, None)
-        if project in self.config_repos:
+        if project in self.config_projects:
             return (True, project)
-        if project in self.project_repos:
+        if project in self.untrusted_projects:
             return (False, project)
         # This should never happen:
         raise Exception("Project %s is neither trusted nor untrusted" %
                         (project,))
 
-    def addConfigRepo(self, project):
-        self.config_repos.append(project)
+    def addConfigProject(self, project):
+        self.config_projects.append(project)
         self._addProject(project)
 
-    def addProjectRepo(self, project):
-        self.project_repos.append(project)
+    def addUntrustedProject(self, project):
+        self.untrusted_projects.append(project)
         self._addProject(project)
@@ -2512,16 +2512,16 @@
         # this tenant.
         self.unparsed_config = None
-        # The list of repos from which we will read main
+        # The list of projects from which we will read full
         # configuration.